==========================
 Oh, oh - Page not found
==========================

This is a custom 404.rst file.

This file should be rendered instead of the default one.

Variables Sphinx substitution should be allowed here.
Example, version: |version|.

Including an image using ``.. image::`` directive,
should also make the extension to fix the URIs.

.. image:: test.png
   :alt: An image


.. image:: images/loudly-crying-face.png
   :alt: Image from folder


Also, using ``.. figure::`` should work as well.

.. figure:: test.png

   Description.


Including an image using an absolute URL should not be modified by the extension:

.. image:: https://read-the-docs-guidelines.readthedocs-hosted.com/_images/logo-dark.png
   :alt: Read the Docs Logo


.. image:: https.png
   :alt: PATH looking as an URL
